@@ -17,10 +17,13 @@ from explainaboard_api_client.model.analysis_result import AnalysisResult
 from explainaboard_api_client.model.any_type import AnyType
 from explainaboard_api_client.model.benchmark import Benchmark
 from explainaboard_api_client.model.benchmark_config import BenchmarkConfig
+from explainaboard_api_client.model.benchmark_config_all_of import BenchmarkConfigAllOf
+from explainaboard_api_client.model.benchmark_create_props import BenchmarkCreateProps
 from explainaboard_api_client.model.benchmark_dataset_config import BenchmarkDatasetConfig
 from explainaboard_api_client.model.benchmark_metric import BenchmarkMetric
 from explainaboard_api_client.model.benchmark_operation_config import BenchmarkOperationConfig
 from explainaboard_api_client.model.benchmark_table_data import BenchmarkTableData
+from explainaboard_api_client.model.benchmark_update_props import BenchmarkUpdateProps
 from explainaboard_api_client.model.benchmark_view_config import BenchmarkViewConfig
 from explainaboard_api_client.model.bucket_performance import BucketPerformance
 from explainaboard_api_client.model.class_label import ClassLabel
